Documentation
¶
Index ¶
Constants ¶
const (
APIServer = "https://api.entrust.net/enterprise/v2"
)
Default client configurations
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddDomainRequest ¶
type AddDomainRequest struct {
DomainName string `json:"domainName"`
VerificationMethod string `json:"verificationMethod"` // enum (DNS, EMAIL, MANUAL, WEB_SERVER)
}
AddDomainRequest contains the paramters to create a new domain
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for the Entrust API
func (*Client) GetDomain ¶
GetDomain requests information about a domain in the account GET /clients/{clientId}/domains/{domain}
func (*Client) GetDomains ¶
GetDomains lists domains based on a filter
type DNSMethod ¶
type DNSMethod struct {
RecordDomain string `json:"recordDomain"`
RecvordType string `json:"recvordType"`
RecordValue string `json:"recordValue"`
}
DNSMethod information
type Domain ¶
type Domain struct {
ClientID int `json:"clientId,omitempty"` // Client id of the client to which the domain belongs to
DomainName string `json:"domainName,omitempty"` // Domain name
EVEligible bool `json:"evEligible,omitempty"` // Whether this domain can be used for EV certificates
EVExpiry time.Time `json:"evExpiry,omitempty"` // Expiry time of verified EV information
OVEligible bool `json:"ovEligible,omitempty"` // Whether this domain can be used for OV certificates
OVExpiry time.Time `json:"ovExpiry,omitempty"` // Expiry time of verified OV information
VerificationMethod string `json:"verificationMethod,omitempty"` // (DNS, EMAIL, MANUAL, WEB_SERVER)
VerificationStatus string `json:"verificationStatus,omitempty"`
DNSMethod *DNSMethod `json:"dnsMethod"`
}
Domain model
type GetDomainsResponse ¶
type GetDomainsResponse struct {
Response
Summary *Summary `json:"summary"`
Domains []Domain `json:"domains"`
}
GetDomainsResponse holds a list of domains
type ReverifyDomainRequest ¶
type ReverifyDomainRequest struct {
VerificationMethod string `json:"verificationMethod"` // enum (DNS, EMAIL, MANUAL, WEB_SERVER)
}
ReverifyDomainRequest schedule domain for revalidation
Click to show internal directories.
Click to hide internal directories.